create type rt as (v text);
create table t(
  k serial primary key,
  literal text, r rt);

create procedure p(tests in text[])
  language plpgsql
as $body$
declare
  stmt constant text :=
    $$insert into t(literal, r) values('?'::text, '?'::rt)$$;
  t text;
begin
  foreach t in array tests loop
    --raise info '%', replace(stmt, '?', t);
    execute replace(stmt, '?', t);
  end loop;
end;
$body$;

call p(array[
    -- Potential for "22P02: malformed record literal" error.

    '( hello \"you\" )',
    '("" hello \"you\" "")',
    '(" hello \"you\" ")',
    '(" hello ""you"" ")',
    '( "hello \"you\"" )',
    '( "hello ""you""" )',

    '(hello)',
    '("hello")',
    '(h\ello)',
    '("h\ello")',
    '(""hello"")',

    '( hello you )',
    '( "hello" "you" )',
    '( "hello you" )',
    '(" hello you ")',
    '( ""hello"" you )',

    '( hello\,\(you\) )',
    '( "hello\,\(you\)" )',
    '(" hello,(you) ")',

    '(\")',
    '("\"")',
    '("""")',

    '(" "hello" ")',
    '( ""hello"" )',

    '(hello you)',
    '("hello you")',

    '( "hello ""to"" you ")',
    '( hello """to""" you )',

    '(h\\ello)',
    '("h\\ello")'
  ]
  );

with a as (
  select
    k,
    '>'||(r).v||'<' as v,
    r::text         as r
  from t)
select
  min(k)   as k,
  v        as "what I want",
  r        as "canonical literal", 
  count(*) as n
from a
group by v, r
order by k, v;

select
  k,
  '>'||(r).v||'<' as "what I want",
  literal         as "what I write",
  r::text         as "canonical literal"
from t order by k;
